# Here you can see data that used in all locales. "int" is
# abbreviation of "International Data".

from .address import *
from .business import *
from .code import *
from .decorator import *
from .development import *
from .datetime import *
from .file import *
from .hardware import *
from .network import *
from .personal import *
from .scientific import *
from .transport import *
from .games import *
