BLOOD_GROUPS = (
    'O+',
    'A+',
    'B+',
    'AB+',
    'O−',
    'A−',
    'B−',
    'AB−',
)

FAVORITE_MUSIC_GENRE = (
    'Pop',
    'Rock',
    'Hard Rock',
    'Rhythm & Blues (R&B)',
    'Country',
    'Rock & Roll',
    'Soul',
    'Country Pop',
    'Pop Rock',
    'Heavy Metal',
    'Progressive Rock',
    'Alternative Rock',
    'Jazz',
    'New Wave',
    'Synthpop',
    'Hip Hop',
    'Folk',
    'New Age',
    'Blues Rock',
    'Ambient',
    'Ambient house',
    'Classic',
    'Neoclassic',
    'Drum and bass',
)

GENDER_SYMBOLS = (
    '♂',
    '♀',
    '⚲',
)

SEXUALITY_SYMBOLS = (
    '⚤',
    '⚢',
    '⚣',
    '⚥',
    '⚧',
    '⚪',
)

ENGLISH_LEVEL = [
    'Beginner',
    'Elementary',
    'Pre - Intermediate',
    'Intermediate',
    'Upper Intermediate',
    'Advanced',
    'Proficiency',
]
